@@ -16,4 +16,6 @@
 # Import APIs into API package:
 from identitylib.photo_client.api.api_versions_api import APIVersionsApi
 from identitylib.photo_client.api.approved_photos_api import ApprovedPhotosApi
-from identitylib.photo_client.api.photos_including_unapproved_api import PhotosIncludingUnapprovedApi
+from identitylib.photo_client.api.permissions_api import PermissionsApi
+from identitylib.photo_client.api.photos_including_unapproved_photos_api import PhotosIncludingUnapprovedPhotosApi
+from identitylib.photo_client.api.unapproved_photos_api import UnapprovedPhotosApi
